/*==============================================================================
// 
//	File: FunctionPIE.h
//
//	Argus Open Numerical Environments - Plug In Extension, Release 1.1
// 
//	Copyright  1996-98 Argus Holdings Ltd.  All rights reserved.
//
//		THIS IS UNPUBLISHED PROPRIETARY SOURCE CODE OF Argus Holdings Ltd..
//		The copyright notice above does not evidence any
//		actual or intended publication of such source code
//
//===============================================================================
//
// Version information:
//	21/09/96 - Version 2. Allow hidden functions
//
//===============================================================================*/

#ifndef _FunctionPIE_H_
#define _FunctionPIE_H_

#ifndef _ANEPIE_H_
#include "ANEPIE.h"
#endif /* _ANEPIE_H_ */

#define FUNCTION_PIE_VERSION 2

#ifdef __cplusplus
extern "C" {
typedef void (*PIEFunctionCall)(const ANE_DOUBLE&		refPtX,
												const ANE_DOUBLE&		refPtY,
												ANE_INT16					numParams,
												const ANE_PTR*			parameters,
												ANE_PTR						funHandle,
												ANE_PTR						reply);
}
#else
typedef void (*PIEFunctionCall)(const ANE_DOUBLE*		refPtX,
												const ANE_DOUBLE*		refPtY,
												ANE_INT16					numParams,
												const ANE_PTR*			parameters,
												ANE_PTR						funHandle,
												ANE_PTR						reply);
#endif

enum EFunctionPIEFlags {
			kFunctionNeedsProject							= 0x1,
			kFunctionHasCategory							= 0x2,
			kFunctionDisplaysDialogWhenDeclared	= 0x4,
			kFunctionIsHidden									= 0x8		/* only since version 2 */
			};

struct FunctionPIEDesc
{

#ifdef __cplusplus
		FunctionPIEDesc() {}

		FunctionPIEDesc(const ANE_STR			_name,
							enum EFunctionPIEFlags		_functionFlags,
							PIEFunctionCall					_address,
							enum EPIENumberType		_returnType,
							ANE_INT16						_numParams,
							ANE_INT16						_numOptParams,
							ANE_STR*						_paramNames,
							enum EPIENumberType*	_paramTypes,
							ANE_PTR							_functionHandle = 0)
			:	
				version(FUNCTION_PIE_VERSION),
				functionFlags(_functionFlags),
				name(_name),
				address(_address),
				returnType(_returnType),
				numParams(_numParams),
				numOptParams(_numOptParams),
				paramNames(_paramNames),
				paramTypes(_paramTypes),
				functionHandle(functionHandle)
			{ }
#endif /* __cplusplus */	

		ANE_INT32						version;
		enum EFunctionPIEFlags		functionFlags;
		ANE_STR							name;
		PIEFunctionCall					address;
		enum EPIENumberType		returnType;
		ANE_INT16						numParams;
		ANE_INT16						numOptParams;
		ANE_STR*						paramNames;
		enum EPIENumberType*	paramTypes;
		ANE_PTR							functionHandle;
		ANE_STR							category;
		ANE_STR							neededProject;
}; /* FunctionPIEDesc */




#endif /* _FunctionPIE_H_ */

/*==============================================================================
//	End File: FunctionPIE.h
//============================================================================*/
